[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Real-Time News client library for Python

[![API Version](https://img.shields.io/badge/api-v4.0.0-blue)](https://developer.factset.com/api-catalog/)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.RealTimeNews/0.20.1)](https://pypi.org/project/fds.sdk.RealTimeNews/v/0.20.1)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Consume FactSet’s StreetAccount news and 3rd party content through an API that seamlessly integrates with
[quotes](https://developer.factset.com/api-catalog/real-time-quotes-api),
[time series](https://developer.factset.com/api-catalog/real-time-time-series-api),
[watchlists](https://developer.factset.com/api-catalog/watchlist-api-digital-portals), and other Functional APIs.

Search for news articles from various news distributors and publishers. Incorporate a multitude of search parameters such as region, category, source, article type and provider-specific meta data, to easily filter out the noise.

All search and list endpoints can be subscribed to receive streamed updates.

News providers include:

* APA
* AWP 
* Businesswire
* Cercle Finance
* Direkt News SE
* Dow Jones News
* dpa
* dpa-AFX 
* EUWAX
* GlobenewsWire
* Kauppalehti
* MT Newswires
* MoneyAM
* newsaktuell
* OMX
* PR Newswire 
* Ritzau Finans
* StreetAccount News
* TDN News
      
See the [Real-Time Quotes API](https://developer.factset.com/api-catalog/real-time-quotes-api) for access to detailed
price and performance information, plus basic support for security identifier cross-reference.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 4.0.0
- SDK version: 0.20.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.RealTimeNews==0.20.1
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.RealTimeNews==0.20.1
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.RealTimeNews
from fds.sdk.RealTimeNews.api import basic_api
from fds.sdk.RealTimeNews.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.RealTimeNews.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.RealTimeNews.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.RealTimeNews.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = basic_api.BasicApi(api_client)
    attributes = [
        "_attributes_example",
    ] # [str] | Limit the attributes returned in the response to the specified set. (optional)

    try:
        # List of asset classes.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_basic_asset_class_list(attributes=attributes)

        pprint(api_response)
    except fds.sdk.RealTimeNews.ApiException as e:
        print("Exception when calling BasicApi->get_basic_asset_class_list: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # List of asset classes.
    #     api_response, http_status_code, response_headers = api_instance.get_basic_asset_class_list_with_http_info(attributes=attributes)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimeNews.ApiException as e:
    #     print("Exception when calling BasicApi->get_basic_asset_class_list: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # List of asset classes.
    #     async_result = api_instance.get_basic_asset_class_list_async(attributes=attributes)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.RealTimeNews.ApiException as e:
    #     print("Exception when calling BasicApi->get_basic_asset_class_list: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # List of asset classes.
    #     async_result = api_instance.get_basic_asset_class_list_with_http_info_async(attributes=attributes)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimeNews.ApiException as e:
    #     print("Exception when calling BasicApi->get_basic_asset_class_list: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.RealTimeNews

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.RealTimeNews.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.RealTimeNews

configuration = fds.sdk.RealTimeNews.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.RealTimeNews

configuration = fds.sdk.RealTimeNews.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.RealTimeNews

configuration = fds.sdk.RealTimeNews.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v4*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BasicApi* | [**get_basic_asset_class_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_asset_class_list) | **GET** /basic/asset-class/list | List of asset classes.
*BasicApi* | [**get_basic_benchmark_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_benchmark_type_list) | **GET** /basic/benchmark/type/list | List of benchmark types.
*BasicApi* | [**get_basic_frequency_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_frequency_type_list) | **GET** /basic/frequency/type/list | List of frequency types.
*BasicApi* | [**get_basic_language_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_language_get) | **GET** /basic/language/get | Details for a language.
*BasicApi* | [**get_basic_language_get_by_code**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_language_get_by_code) | **GET** /basic/language/get-by-code | Details for a language identified by code.
*BasicApi* | [**get_basic_language_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_language_list) | **GET** /basic/language/list | List of languages.
*BasicApi* | [**get_basic_market_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_market_get) | **GET** /basic/market/get | Details of a market.
*BasicApi* | [**get_basic_market_group_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_market_group_list) | **GET** /basic/market/group/list | List of market groups.
*BasicApi* | [**get_basic_market_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_market_type_list) | **GET** /basic/market/type/list | List of market types.
*BasicApi* | [**get_basic_media_kind_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_media_kind_list) | **GET** /basic/media/kind/list | List of media kinds.
*BasicApi* | [**get_basic_region_continent_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_continent_get) | **GET** /basic/region/continent/get | Details for a continent.
*BasicApi* | [**get_basic_region_continent_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_continent_list) | **GET** /basic/region/continent/list | List of continents.
*BasicApi* | [**get_basic_region_country_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_country_get) | **GET** /basic/region/country/get | Details for a country.
*BasicApi* | [**get_basic_region_country_get_by_code**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_country_get_by_code) | **GET** /basic/region/country/get-by-code | Details for a country identified by code.
*BasicApi* | [**get_basic_region_country_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_country_list) | **GET** /basic/region/country/list | List of countries.
*BasicApi* | [**get_basic_region_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_get) | **GET** /basic/region/get | Details for a region.
*BasicApi* | [**get_basic_region_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_region_list) | **GET** /basic/region/list | List of regions.
*BasicApi* | [**get_basic_timezone_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_timezone_get) | **GET** /basic/timezone/get | Details of a timezone.
*BasicApi* | [**get_basic_timezone_get_by_name**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_timezone_get_by_name) | **GET** /basic/timezone/get-by-name | Details of a timezone identified by name.
*BasicApi* | [**get_basic_value_unit_alternative_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_value_unit_alternative_list) | **GET** /basic/value-unit/alternative/list | List of alternative units.
*BasicApi* | [**get_basic_value_unit_currency_fractional_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_value_unit_currency_fractional_get) | **GET** /basic/value-unit/currency/fractional/get | Details of a fractional currency.
*BasicApi* | [**get_basic_value_unit_currency_fractional_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_value_unit_currency_fractional_list) | **GET** /basic/value-unit/currency/fractional/list | List of fractional currencies.
*BasicApi* | [**get_basic_value_unit_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#get_basic_value_unit_get) | **GET** /basic/value-unit/get | Details of a value unit.
*BasicApi* | [**post_basic_background_text_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_background_text_type_list) | **POST** /basic/background-text/type/list | List of background text types.
*BasicApi* | [**post_basic_delivery_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_delivery_list) | **POST** /basic/delivery/list | List of deliveries.
*BasicApi* | [**post_basic_market_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_market_list) | **POST** /basic/market/list | List of markets.
*BasicApi* | [**post_basic_media_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_media_type_list) | **POST** /basic/media/type/list | List of Internet media types.
*BasicApi* | [**post_basic_mic_operating_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_mic_operating_list) | **POST** /basic/mic/operating/list | List of operating market identifier codes (MIC).
*BasicApi* | [**post_basic_timezone_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_timezone_list) | **POST** /basic/timezone/list | List of timezones.
*BasicApi* | [**post_basic_value_unit_currency_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_value_unit_currency_list) | **POST** /basic/value-unit/currency/list | List of currencies.
*BasicApi* | [**post_basic_value_unit_currency_main_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_value_unit_currency_main_list) | **POST** /basic/value-unit/currency/main/list | List of main currencies.
*BasicApi* | [**post_basic_value_unit_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/BasicApi.md#post_basic_value_unit_list) | **POST** /basic/value-unit/list | List of value units.
*CategoryApi* | [**get_category_dataset_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_dataset_list) | **GET** /category/dataset/list | List of entitled category datasets.
*CategoryApi* | [**get_category_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_get) | **GET** /category/get | Details of a category.
*CategoryApi* | [**get_category_instrument_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_instrument_list) | **GET** /category/instrument/list | List of instruments where a specific dataset has assigned a given category.
*CategoryApi* | [**get_category_level_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_level_get) | **GET** /category/level/get | Details of a category level.
*CategoryApi* | [**get_category_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_list) | **GET** /category/list | List of categories.
*CategoryApi* | [**get_category_list_by_level**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_list_by_level) | **GET** /category/list-by-level | List of categories assigned to a category level.
*CategoryApi* | [**get_category_list_by_system**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_list_by_system) | **GET** /category/list-by-system | List of categories assigned to a category system.
*CategoryApi* | [**get_category_path_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_path_get) | **GET** /category/path/get | Path from the first level to the level of a specific category.
*CategoryApi* | [**get_category_system_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_system_get) | **GET** /category/system/get | Details of an entitled category system.
*CategoryApi* | [**get_category_system_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_system_list) | **GET** /category/system/list | List of entitled category systems.
*CategoryApi* | [**get_category_system_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CategoryApi.md#get_category_system_type_list) | **GET** /category/system/type/list | List of category system types.
*NewsApi* | [**get_news_article_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_article_get) | **GET** /news/article/get | Details for a news article.
*NewsApi* | [**get_news_article_type_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_article_type_get) | **GET** /news/article/type/get | Details for a news article type.
*NewsApi* | [**get_news_article_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_article_type_list) | **GET** /news/article/type/list | List of news article types.
*NewsApi* | [**get_news_distributor_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_distributor_get) | **GET** /news/distributor/get | Details of a distributor.
*NewsApi* | [**get_news_distributor_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_distributor_list) | **GET** /news/distributor/list | List of distributors.
*NewsApi* | [**get_news_publisher_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_publisher_get) | **GET** /news/publisher/get | Details of a publisher.
*NewsApi* | [**get_news_publisher_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_publisher_list) | **GET** /news/publisher/list | List of publishers.
*NewsApi* | [**get_news_publisher_list_by_distributor**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#get_news_publisher_list_by_distributor) | **GET** /news/publisher/list-by-distributor | List of publishers provided by the given distributor.
*NewsApi* | [**post_news_article_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_list) | **POST** /news/article/list | List of news articles.
*NewsApi* | [**post_news_article_list_by_chain**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_list_by_chain) | **POST** /news/article/list-by-chain | List news articles of an article chain.
*NewsApi* | [**post_news_article_list_by_index**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_list_by_index) | **POST** /news/article/list-by-index | News articles for instruments that are constituents of the given indices.
*NewsApi* | [**post_news_article_list_by_instrument**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_list_by_instrument) | **POST** /news/article/list-by-instrument | News articles for instruments.
*NewsApi* | [**post_news_article_list_by_media_kind**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_list_by_media_kind) | **POST** /news/article/list-by-media-kind | List news articles which contain media of specific media kinds.
*NewsApi* | [**post_news_article_search_by_text**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_article_search_by_text) | **POST** /news/article/search-by-text | Search for news articles using a fulltext search.
*NewsApi* | [**post_news_publisher_search_by_name**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/NewsApi.md#post_news_publisher_search_by_name) | **POST** /news/publisher/search-by-name | Search for publishers.


## Documentation For Models

 - [AttributesMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/AttributesMember.md)
 - [CursorBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/CursorBasedPaginationOutputObjectWithoutTotal.md)
 - [GetBasicAssetClassListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicAssetClassListDataItems.md)
 - [GetBasicBenchmarkTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicBenchmarkTypeListDataItems.md)
 - [GetBasicFrequencyTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicFrequencyTypeListDataItems.md)
 - [GetBasicLanguageListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicLanguageListDataItems.md)
 - [GetBasicMarketGroupListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicMarketGroupListDataItems.md)
 - [GetBasicMarketTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicMarketTypeListDataItems.md)
 - [GetBasicMediaKindListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicMediaKindListDataItems.md)
 - [GetBasicRegionContinentGetDataCountriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionContinentGetDataCountriesItems.md)
 - [GetBasicRegionContinentListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionContinentListDataItems.md)
 - [GetBasicRegionCountryGetByCodeDataSubdivisionsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionCountryGetByCodeDataSubdivisionsItems.md)
 - [GetBasicRegionCountryGetDataSubdivisionsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionCountryGetDataSubdivisionsItems.md)
 - [GetBasicRegionCountryListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionCountryListDataItems.md)
 - [GetBasicRegionGetDataNestedRegionsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionGetDataNestedRegionsItems.md)
 - [GetBasicRegionListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicRegionListDataItems.md)
 - [GetBasicValueUnitAlternativeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicValueUnitAlternativeListDataItems.md)
 - [GetBasicValueUnitCurrencyFractionalListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicValueUnitCurrencyFractionalListDataItems.md)
 - [GetBasicValueUnitCurrencyFractionalListDataItemsMainCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetBasicValueUnitCurrencyFractionalListDataItemsMainCurrency.md)
 - [GetCategoryDatasetListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryDatasetListDataItems.md)
 - [GetCategoryDatasetListDataItemsDelivery](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryDatasetListDataItemsDelivery.md)
 - [GetCategoryDatasetListDataItemsSystem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryDatasetListDataItemsSystem.md)
 - [GetCategoryInstrumentListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryInstrumentListDataItems.md)
 - [GetCategoryListByLevelDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListByLevelDataCategoriesItems.md)
 - [GetCategoryListByLevelDataCategoriesItemsParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListByLevelDataCategoriesItemsParent.md)
 - [GetCategoryListBySystemDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListBySystemDataCategoriesItems.md)
 - [GetCategoryListBySystemDataCategoriesItemsLevel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListBySystemDataCategoriesItemsLevel.md)
 - [GetCategoryListBySystemDataCategoriesItemsParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListBySystemDataCategoriesItemsParent.md)
 - [GetCategoryListDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListDataCategoriesItems.md)
 - [GetCategoryListDataCategoriesItemsLevel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListDataCategoriesItemsLevel.md)
 - [GetCategoryListDataCategoriesItemsParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryListDataCategoriesItemsParent.md)
 - [GetCategoryPathGetDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategoryPathGetDataCategoriesItems.md)
 - [GetCategorySystemGetDataLevelsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategorySystemGetDataLevelsItems.md)
 - [GetCategorySystemListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategorySystemListDataItems.md)
 - [GetCategorySystemListDataItemsType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategorySystemListDataItemsType.md)
 - [GetCategorySystemTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetCategorySystemTypeListDataItems.md)
 - [GetNewsArticleGetDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsArticleGetDataCategoriesItems.md)
 - [GetNewsArticleGetDataInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsArticleGetDataInstrumentsItems.md)
 - [GetNewsArticleGetDataMediaItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsArticleGetDataMediaItems.md)
 - [GetNewsArticleGetDataTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsArticleGetDataTypesItems.md)
 - [GetNewsArticleTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsArticleTypeListDataItems.md)
 - [GetNewsDistributorListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsDistributorListDataItems.md)
 - [GetNewsDistributorListDataItemsDelivery](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsDistributorListDataItemsDelivery.md)
 - [GetNewsPublisherListByDistributorDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsPublisherListByDistributorDataItems.md)
 - [GetNewsPublisherListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsPublisherListDataItems.md)
 - [GetNewsPublisherListDataItemsDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/GetNewsPublisherListDataItemsDistributor.md)
 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse200.md)
 - [InlineResponse2001](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2001.md)
 - [InlineResponse20010](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20010.md)
 - [InlineResponse20011](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20011.md)
 - [InlineResponse20012](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20012.md)
 - [InlineResponse20013](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20013.md)
 - [InlineResponse20014](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20014.md)
 - [InlineResponse20015](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20015.md)
 - [InlineResponse20015Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20015Data.md)
 - [InlineResponse20016](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20016.md)
 - [InlineResponse20017](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20017.md)
 - [InlineResponse20017Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20017Data.md)
 - [InlineResponse20018](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20018.md)
 - [InlineResponse20019](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20019.md)
 - [InlineResponse20019Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20019Data.md)
 - [InlineResponse2002](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2002.md)
 - [InlineResponse20020](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20020.md)
 - [InlineResponse20020Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20020Data.md)
 - [InlineResponse20021](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20021.md)
 - [InlineResponse20022](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20022.md)
 - [InlineResponse20022Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20022Data.md)
 - [InlineResponse20023](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20023.md)
 - [InlineResponse20023Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20023Data.md)
 - [InlineResponse20024](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20024.md)
 - [InlineResponse20025](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20025.md)
 - [InlineResponse20025Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20025Data.md)
 - [InlineResponse20026](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20026.md)
 - [InlineResponse20027](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20027.md)
 - [InlineResponse20028](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20028.md)
 - [InlineResponse20029](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20029.md)
 - [InlineResponse20029Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20029Data.md)
 - [InlineResponse20029DataMainCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20029DataMainCurrency.md)
 - [InlineResponse2003](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2003.md)
 - [InlineResponse20030](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20030.md)
 - [InlineResponse20031](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20031.md)
 - [InlineResponse20032](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032.md)
 - [InlineResponse20032Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032Data.md)
 - [InlineResponse20032DataLevel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032DataLevel.md)
 - [InlineResponse20032DataParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032DataParent.md)
 - [InlineResponse20032DataParentLevel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032DataParentLevel.md)
 - [InlineResponse20032DataSystem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20032DataSystem.md)
 - [InlineResponse20033](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20033.md)
 - [InlineResponse20033Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20033Data.md)
 - [InlineResponse20033DataSystem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20033DataSystem.md)
 - [InlineResponse20034](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20034.md)
 - [InlineResponse20034Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20034Data.md)
 - [InlineResponse20034DataParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20034DataParent.md)
 - [InlineResponse20034DataSystem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20034DataSystem.md)
 - [InlineResponse20034Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20034Meta.md)
 - [InlineResponse20035](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20035.md)
 - [InlineResponse20035Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20035Data.md)
 - [InlineResponse20036](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20036.md)
 - [InlineResponse20037](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20037.md)
 - [InlineResponse20037Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20037Meta.md)
 - [InlineResponse20038](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20038.md)
 - [InlineResponse20038Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20038Data.md)
 - [InlineResponse20038DataSystem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20038DataSystem.md)
 - [InlineResponse20039](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20039.md)
 - [InlineResponse20039Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20039Data.md)
 - [InlineResponse2004](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2004.md)
 - [InlineResponse20040](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20040.md)
 - [InlineResponse20040Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20040Data.md)
 - [InlineResponse20040DataType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20040DataType.md)
 - [InlineResponse20041](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20041.md)
 - [InlineResponse20042](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20042.md)
 - [InlineResponse20043](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20043.md)
 - [InlineResponse20043Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20043Data.md)
 - [InlineResponse20043DataDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20043DataDistributor.md)
 - [InlineResponse20043DataLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20043DataLanguage.md)
 - [InlineResponse20043DataPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20043DataPublisher.md)
 - [InlineResponse20044](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20044.md)
 - [InlineResponse20044Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20044Meta.md)
 - [InlineResponse20045](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20045.md)
 - [InlineResponse20045Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20045Data.md)
 - [InlineResponse20045DataDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20045DataDistributor.md)
 - [InlineResponse20045DataPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20045DataPublisher.md)
 - [InlineResponse20046](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20046.md)
 - [InlineResponse20046Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20046Data.md)
 - [InlineResponse20047](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20047.md)
 - [InlineResponse20047Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20047Data.md)
 - [InlineResponse20048](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20048.md)
 - [InlineResponse20049](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20049.md)
 - [InlineResponse2005](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2005.md)
 - [InlineResponse20050](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20050.md)
 - [InlineResponse20050Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20050Data.md)
 - [InlineResponse20051](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20051.md)
 - [InlineResponse20052](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20052.md)
 - [InlineResponse20052Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20052Data.md)
 - [InlineResponse20052DataDelivery](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20052DataDelivery.md)
 - [InlineResponse20053](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20053.md)
 - [InlineResponse20054](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20054.md)
 - [InlineResponse20054Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20054Data.md)
 - [InlineResponse20054DataDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20054DataDistributor.md)
 - [InlineResponse20055](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20055.md)
 - [InlineResponse20056](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20056.md)
 - [InlineResponse20057](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse20057.md)
 - [InlineResponse2005Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2005Data.md)
 - [InlineResponse2006](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2006.md)
 - [InlineResponse2006Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2006Data.md)
 - [InlineResponse2007](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2007.md)
 - [InlineResponse2008](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008.md)
 - [InlineResponse2008Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008Data.md)
 - [InlineResponse2008DataCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008DataCountry.md)
 - [InlineResponse2008DataGroup](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008DataGroup.md)
 - [InlineResponse2008DataTimezone](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008DataTimezone.md)
 - [InlineResponse2008DataType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2008DataType.md)
 - [InlineResponse2009](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2009.md)
 - [InlineResponse2009Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse2009Meta.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/InlineResponse200Meta.md)
 - [LanguageMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/LanguageMember.md)
 - [OffsetBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/OffsetBasedPaginationOutputObject.md)
 - [OffsetBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/OffsetBasedPaginationOutputObjectWithoutTotal.md)
 - [PartialOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PartialOutputObject.md)
 - [PostBasicBackgroundTextTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicBackgroundTextTypeListDataItems.md)
 - [PostBasicBackgroundTextTypeListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicBackgroundTextTypeListRequest.md)
 - [PostBasicBackgroundTextTypeListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicBackgroundTextTypeListRequestData.md)
 - [PostBasicBackgroundTextTypeListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicBackgroundTextTypeListRequestDataFilter.md)
 - [PostBasicBackgroundTextTypeListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicBackgroundTextTypeListRequestMeta.md)
 - [PostBasicDeliveryListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicDeliveryListDataItems.md)
 - [PostBasicDeliveryListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicDeliveryListRequest.md)
 - [PostBasicDeliveryListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicDeliveryListRequestData.md)
 - [PostBasicDeliveryListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicDeliveryListRequestDataFilter.md)
 - [PostBasicDeliveryListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicDeliveryListRequestMeta.md)
 - [PostBasicMarketListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListDataItems.md)
 - [PostBasicMarketListDataItemsCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListDataItemsCountry.md)
 - [PostBasicMarketListDataItemsGroup](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListDataItemsGroup.md)
 - [PostBasicMarketListDataItemsTimezone](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListDataItemsTimezone.md)
 - [PostBasicMarketListDataItemsType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListDataItemsType.md)
 - [PostBasicMarketListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequest.md)
 - [PostBasicMarketListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequestData.md)
 - [PostBasicMarketListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequestDataFilter.md)
 - [PostBasicMarketListRequestDataFilterMarkets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequestDataFilterMarkets.md)
 - [PostBasicMarketListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequestMeta.md)
 - [PostBasicMarketListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMarketListRequestMetaPagination.md)
 - [PostBasicMediaTypeListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListDataItems.md)
 - [PostBasicMediaTypeListDataItemsKind](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListDataItemsKind.md)
 - [PostBasicMediaTypeListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListRequest.md)
 - [PostBasicMediaTypeListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListRequestData.md)
 - [PostBasicMediaTypeListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListRequestDataFilter.md)
 - [PostBasicMediaTypeListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMediaTypeListRequestMeta.md)
 - [PostBasicMicOperatingListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMicOperatingListDataItems.md)
 - [PostBasicMicOperatingListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMicOperatingListRequest.md)
 - [PostBasicMicOperatingListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMicOperatingListRequestData.md)
 - [PostBasicMicOperatingListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMicOperatingListRequestDataFilter.md)
 - [PostBasicMicOperatingListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicMicOperatingListRequestMeta.md)
 - [PostBasicTimezoneListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicTimezoneListDataItems.md)
 - [PostBasicTimezoneListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicTimezoneListRequest.md)
 - [PostBasicTimezoneListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicTimezoneListRequestData.md)
 - [PostBasicTimezoneListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicTimezoneListRequestDataFilter.md)
 - [PostBasicValueUnitCurrencyListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyListDataItems.md)
 - [PostBasicValueUnitCurrencyListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyListRequest.md)
 - [PostBasicValueUnitCurrencyListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyListRequestMeta.md)
 - [PostBasicValueUnitCurrencyMainListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyMainListDataItems.md)
 - [PostBasicValueUnitCurrencyMainListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyMainListRequest.md)
 - [PostBasicValueUnitCurrencyMainListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyMainListRequestData.md)
 - [PostBasicValueUnitCurrencyMainListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitCurrencyMainListRequestDataFilter.md)
 - [PostBasicValueUnitListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitListDataItems.md)
 - [PostBasicValueUnitListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitListRequest.md)
 - [PostBasicValueUnitListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitListRequestData.md)
 - [PostBasicValueUnitListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitListRequestDataFilter.md)
 - [PostBasicValueUnitListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostBasicValueUnitListRequestMeta.md)
 - [PostNewsArticleListByChainDataArticlesCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainDataArticlesCategoriesItems.md)
 - [PostNewsArticleListByChainDataArticlesInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainDataArticlesInstrumentsItems.md)
 - [PostNewsArticleListByChainDataArticlesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainDataArticlesItems.md)
 - [PostNewsArticleListByChainDataArticlesItemsLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainDataArticlesItemsLanguage.md)
 - [PostNewsArticleListByChainDataArticlesTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainDataArticlesTypesItems.md)
 - [PostNewsArticleListByChainRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequest.md)
 - [PostNewsArticleListByChainRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequestData.md)
 - [PostNewsArticleListByChainRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequestDataFilter.md)
 - [PostNewsArticleListByChainRequestDataFilterRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequestDataFilterRange.md)
 - [PostNewsArticleListByChainRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequestMeta.md)
 - [PostNewsArticleListByChainRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByChainRequestMetaSubscription.md)
 - [PostNewsArticleListByIndexDataArticlesCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesCategoriesItems.md)
 - [PostNewsArticleListByIndexDataArticlesInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesInstrumentsItems.md)
 - [PostNewsArticleListByIndexDataArticlesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesItems.md)
 - [PostNewsArticleListByIndexDataArticlesItemsChain](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesItemsChain.md)
 - [PostNewsArticleListByIndexDataArticlesItemsDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesItemsDistributor.md)
 - [PostNewsArticleListByIndexDataArticlesItemsLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesItemsLanguage.md)
 - [PostNewsArticleListByIndexDataArticlesItemsPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesItemsPublisher.md)
 - [PostNewsArticleListByIndexDataArticlesTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataArticlesTypesItems.md)
 - [PostNewsArticleListByIndexDataIdentifiersItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataIdentifiersItems.md)
 - [PostNewsArticleListByIndexDataIdentifiersItemsStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexDataIdentifiersItemsStatus.md)
 - [PostNewsArticleListByIndexRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequest.md)
 - [PostNewsArticleListByIndexRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestData.md)
 - [PostNewsArticleListByIndexRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilter.md)
 - [PostNewsArticleListByIndexRequestDataFilterCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterCategories.md)
 - [PostNewsArticleListByIndexRequestDataFilterDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterDistributor.md)
 - [PostNewsArticleListByIndexRequestDataFilterLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterLanguage.md)
 - [PostNewsArticleListByIndexRequestDataFilterPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterPublisher.md)
 - [PostNewsArticleListByIndexRequestDataFilterRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterRegions.md)
 - [PostNewsArticleListByIndexRequestDataFilterTypes](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataFilterTypes.md)
 - [PostNewsArticleListByIndexRequestDataIdentifier](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestDataIdentifier.md)
 - [PostNewsArticleListByIndexRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestMeta.md)
 - [PostNewsArticleListByIndexRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByIndexRequestMetaSubscription.md)
 - [PostNewsArticleListByInstrumentDataArticlesCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesCategoriesItems.md)
 - [PostNewsArticleListByInstrumentDataArticlesInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesInstrumentsItems.md)
 - [PostNewsArticleListByInstrumentDataArticlesInstrumentsItemsFsym](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesInstrumentsItemsFsym.md)
 - [PostNewsArticleListByInstrumentDataArticlesInstrumentsItemsFsymSecurity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesInstrumentsItemsFsymSecurity.md)
 - [PostNewsArticleListByInstrumentDataArticlesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesItems.md)
 - [PostNewsArticleListByInstrumentDataArticlesItemsChain](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesItemsChain.md)
 - [PostNewsArticleListByInstrumentDataArticlesItemsDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesItemsDistributor.md)
 - [PostNewsArticleListByInstrumentDataArticlesItemsLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesItemsLanguage.md)
 - [PostNewsArticleListByInstrumentDataArticlesItemsPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesItemsPublisher.md)
 - [PostNewsArticleListByInstrumentDataArticlesTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataArticlesTypesItems.md)
 - [PostNewsArticleListByInstrumentDataIdentifiersItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataIdentifiersItems.md)
 - [PostNewsArticleListByInstrumentDataIdentifiersItemsStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentDataIdentifiersItemsStatus.md)
 - [PostNewsArticleListByInstrumentRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequest.md)
 - [PostNewsArticleListByInstrumentRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestData.md)
 - [PostNewsArticleListByInstrumentRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataFilter.md)
 - [PostNewsArticleListByInstrumentRequestDataFilterCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataFilterCategories.md)
 - [PostNewsArticleListByInstrumentRequestDataFilterDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataFilterDistributor.md)
 - [PostNewsArticleListByInstrumentRequestDataFilterPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataFilterPublisher.md)
 - [PostNewsArticleListByInstrumentRequestDataFilterRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataFilterRange.md)
 - [PostNewsArticleListByInstrumentRequestDataIdentifier](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestDataIdentifier.md)
 - [PostNewsArticleListByInstrumentRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestMeta.md)
 - [PostNewsArticleListByInstrumentRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByInstrumentRequestMetaSubscription.md)
 - [PostNewsArticleListByMediaKindDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataCategoriesItems.md)
 - [PostNewsArticleListByMediaKindDataInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataInstrumentsItems.md)
 - [PostNewsArticleListByMediaKindDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataItems.md)
 - [PostNewsArticleListByMediaKindDataItemsChain](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataItemsChain.md)
 - [PostNewsArticleListByMediaKindDataItemsDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataItemsDistributor.md)
 - [PostNewsArticleListByMediaKindDataItemsLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataItemsLanguage.md)
 - [PostNewsArticleListByMediaKindDataItemsPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataItemsPublisher.md)
 - [PostNewsArticleListByMediaKindDataTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindDataTypesItems.md)
 - [PostNewsArticleListByMediaKindRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequest.md)
 - [PostNewsArticleListByMediaKindRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestData.md)
 - [PostNewsArticleListByMediaKindRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestDataFilter.md)
 - [PostNewsArticleListByMediaKindRequestDataFilterDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestDataFilterDistributor.md)
 - [PostNewsArticleListByMediaKindRequestDataFilterLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestDataFilterLanguage.md)
 - [PostNewsArticleListByMediaKindRequestDataFilterPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestDataFilterPublisher.md)
 - [PostNewsArticleListByMediaKindRequestDataFilterTypes](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestDataFilterTypes.md)
 - [PostNewsArticleListByMediaKindRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestMeta.md)
 - [PostNewsArticleListByMediaKindRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListByMediaKindRequestMetaSubscription.md)
 - [PostNewsArticleListDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListDataCategoriesItems.md)
 - [PostNewsArticleListDataInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListDataInstrumentsItems.md)
 - [PostNewsArticleListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListDataItems.md)
 - [PostNewsArticleListDataItemsChain](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListDataItemsChain.md)
 - [PostNewsArticleListDataTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListDataTypesItems.md)
 - [PostNewsArticleListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequest.md)
 - [PostNewsArticleListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestData.md)
 - [PostNewsArticleListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilter.md)
 - [PostNewsArticleListRequestDataFilterCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterCategories.md)
 - [PostNewsArticleListRequestDataFilterDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterDistributor.md)
 - [PostNewsArticleListRequestDataFilterLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterLanguage.md)
 - [PostNewsArticleListRequestDataFilterPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterPublisher.md)
 - [PostNewsArticleListRequestDataFilterRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterRange.md)
 - [PostNewsArticleListRequestDataFilterRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterRegions.md)
 - [PostNewsArticleListRequestDataFilterTypes](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestDataFilterTypes.md)
 - [PostNewsArticleListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestMeta.md)
 - [PostNewsArticleListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestMetaPagination.md)
 - [PostNewsArticleListRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleListRequestMetaSubscription.md)
 - [PostNewsArticleSearchByTextDataCategoriesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCategoriesItems.md)
 - [PostNewsArticleSearchByTextDataCriteriaItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItems.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsCategories.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsDistributor.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsIndices](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsIndices.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsInstruments](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsInstruments.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsLanguage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsLanguage.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsPublisher.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsRegions.md)
 - [PostNewsArticleSearchByTextDataCriteriaItemsTypes](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataCriteriaItemsTypes.md)
 - [PostNewsArticleSearchByTextDataInstrumentsItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataInstrumentsItems.md)
 - [PostNewsArticleSearchByTextDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataItems.md)
 - [PostNewsArticleSearchByTextDataItemsPublisher](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataItemsPublisher.md)
 - [PostNewsArticleSearchByTextDataTypesItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextDataTypesItems.md)
 - [PostNewsArticleSearchByTextRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequest.md)
 - [PostNewsArticleSearchByTextRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequestData.md)
 - [PostNewsArticleSearchByTextRequestDataText](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequestDataText.md)
 - [PostNewsArticleSearchByTextRequestDataTextCriteria](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequestDataTextCriteria.md)
 - [PostNewsArticleSearchByTextRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequestMeta.md)
 - [PostNewsArticleSearchByTextRequestMetaSubscription](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsArticleSearchByTextRequestMetaSubscription.md)
 - [PostNewsPublisherSearchByNameDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameDataItems.md)
 - [PostNewsPublisherSearchByNameRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequest.md)
 - [PostNewsPublisherSearchByNameRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequestData.md)
 - [PostNewsPublisherSearchByNameRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequestDataFilter.md)
 - [PostNewsPublisherSearchByNameRequestDataFilterDelivery](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequestDataFilterDelivery.md)
 - [PostNewsPublisherSearchByNameRequestDataFilterDistributor](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequestDataFilterDistributor.md)
 - [PostNewsPublisherSearchByNameRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/PostNewsPublisherSearchByNameRequestMeta.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeNews/v4/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.RealTimeNews.apis and fds.sdk.RealTimeNews.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.RealTimeNews.api.default_api import DefaultApi`
- `from fds.sdk.RealTimeNews.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.RealTimeNews
from fds.sdk.RealTimeNews.apis import *
from fds.sdk.RealTimeNews.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

